ref: Rename test.InitForTest to test.V23Init

The test.Init function remains unchanged.

Change-Id: Ic3838daea7a5d57bf4efe34b6a6d5e446c835ae0
MultiPart: 2/3
diff --git a/test/init.go b/test/init.go
index f01b1df..395cab7 100644
--- a/test/init.go
+++ b/test/init.go
@@ -63,11 +63,11 @@
 	once.Do(init)
 }
 
 // InitForTest initializes a new context.T and sets a freshly created principal
 // (with a single self-signed blessing) on it. The principal setting step is
 // skipped if this function is invoked from a process run using the modules
 // package.
-func InitForTest() (*context.T, v23.Shutdown) {
+func V23Init() (*context.T, v23.Shutdown) {
 	ctx, shutdown := v23.Init()
 	if len(os.Getenv("V23_SHELL_HELPER_PROCESS_ENTRY_POINT")) != 0 {
 		return ctx, shutdown
@@ -63,11 +63,11 @@
 }
 
-// InitForTest initializes a new context.T and sets a freshly created principal
+// V23Init initializes a new context.T and sets a freshly created principal
 // (with a single self-signed blessing) on it. The principal setting step is
 // skipped if this function is invoked from a process run using the modules